!     =========================================================================
!     Library: Useful Constants Library
!     
!     This library contains modules of useful constants
!     Contains: - math_constants
!               - physics_consants
!               - SM_particle_masses
!               - hadron_properties
!     =========================================================================
      module math_constants
      implicit none
      real(8), parameter :: pi  = 4.d0*datan(1.d0)
      real(8), parameter :: ee  = dexp(1.d0)
      real(8), parameter :: zero = 0.d0
      complex(8), parameter :: xi = dcmplx(0.d0,1.d0)
      end module math_constants
!     -------------------------------------------------------------------------
      module physics_constants
      implicit none
      real(8), parameter :: alpha  = 1.d0/137.035999d0
      end module

!     -------------------------------------------------------------------------
      module hadron_properties
      use physics_constants
!     All Masses Reported in GeV
      implicit none
!     ===========
!     MESONS    
!     ===========
!     Light unflavored - Masses
      real(8), parameter :: xMpic = 0.13957018d0 !pion (charged)
      real(8), parameter :: xMpi0 = 0.1349766d0  !pion (neutral)
      real(8), parameter :: xMeta = 0.547862d0   !eta
      real(8), parameter :: xMrho = 0.77526d0    !rho(770)
      real(8), parameter :: xMjpsi = 3.097d0     !J/psi
      real(8), parameter :: xMomg = 0.78265d0    !omega(782)
      real(8), parameter :: xMetp = 0.95778d0    !eta'(958)
      real(8), parameter :: xMf0  = 0.990d0      !f0(980)
      real(8), parameter :: xMa0  = 0.980d0      !a0(980)
      real(8), parameter :: xMphi = 1.019461d0   !phi(1020)
      real(8), parameter :: xMa1  = 1.230d0      !a1(1260)
      real(8), parameter :: xMf2  = 1.2751d0     !f2(1270)
!     Light unflavored - Lifetime (seconds)
      real(8), parameter :: xTpic = 2.6033d-8    !pion (charged)
      real(8), parameter :: xTpi0 = 8.52d-17     !pion (neutral)
      
!     Decay constant
      real(8), parameter :: xFjpsi = 0.278d0	 !J/psi (GeV)
!     ===========
!     BARYONS
!     ===========
      real(8), parameter :: xMpro = 0.9383d0
      real(8), parameter :: xMpcnarrow = 4.45d0	!Pc(4450)

      !Widths in GeV
      real(8), parameter :: xGpcnarrow = 0.039d0      !Pc(4450)
      end module hadron_properties
